# LiteSpeed Server Appliance

An Open Source Appliance from Robbie Ferguson
(c) 2025 Robbie Ferguson – Licensed under Apache 2.0

## Overview

The LiteSpeed Server Appliance is a fast, modern web server environment built on:

* **OpenLiteSpeed** for blazing-fast HTTP/3-powered web serving
* **MariaDB** for robust, MySQL-compatible databases
* **PHP 8.2** and essential extensions
* **Redis**, GZIP, and Brotli for performance and caching
* **Self-signed SSL** out of the box, with **Let's Encrypt support via Certbot**

It's perfect for hosting high-performance websites and apps, including—but not limited to—WordPress.

---

## Default Settings

* Web Root: `/var/www/html`
* WebAdmin Panel: `https://your-server-ip:7080`

  * Default login: `admin / 123456`
  * Change password: `/usr/local/lsws/admin/misc/admpass.sh`
* PHP Info File: `http://your-server/info.php`
* UFW: Enabled (Ports 22, 80, 443, 7080 allowed)

---

## SSL Setup

### ✅ Already Configured

* A **self-signed SSL certificate** is preinstalled and active for your site on port 443.
* This lets you test HTTPS immediately with a browser security exception.

### 🔒 Upgrade to Let's Encrypt SSL (Recommended)

1. Ensure your domain points to this server.
2. Run:

   ```bash
   certbot certonly --webroot -w /var/www/html -d yourdomain.com
   ```
3. Update LiteSpeed's config to use the real cert:

   ```
   certFile                 /etc/letsencrypt/live/yourdomain.com/fullchain.pem
   keyFile                  /etc/letsencrypt/live/yourdomain.com/privkey.pem
   ```
4. Restart LiteSpeed:

   ```bash
   systemctl restart lsws
   ```

---

## Notes

* The appliance does **not** include WordPress or any CMS by default. Install your web site or CMS to /var/www/html/
* All configuration happens during the build phase—end users can begin using the server immediately.
* File uploads, rewrite rules, caching behavior, and database settings can be customized as needed.

---

## Support & Licensing

This appliance is open source and released under the **Apache 2.0 license**. Contributions and forks are welcome.

---

Enjoy your high-performance web server!
